AddCommand class

Command to add a new flavor to the project.

Constructors

AddCommand({AppLogger? logger})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(List<String> args) Future<void>
Prompts the user for a flavor name if not provided in args, validates it, and sets up the project structure for the new flavor.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited