BuildCommand class
Command to build the Flutter application for a specific platform and flavor.
Constructors
- BuildCommand({AppLogger? logger})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
List< String> args) → Future<void> - Prompts for build target and flavor if not provided, validates environment, and builds the application using the Flutter CLI.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited