RunCommand class

Command to run the Flutter application with a specific flavor.

Constructors

RunCommand({AppLogger? logger})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(List<String> args) Future<void>
Prompts for flavor and build mode if not provided, validates environment, and runs the application using the Flutter CLI.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited