isInitialized static method
Returns true if the project has been initialized with flavor_cli.
Implementation
static bool isInitialized() {
return File(_configPath).existsSync() ||
File(p.join(root, '.flavor_cli.json')).existsSync();
}
Returns true if the project has been initialized with flavor_cli.
static bool isInitialized() {
return File(_configPath).existsSync() ||
File(p.join(root, '.flavor_cli.json')).existsSync();
}