FileService class

Service for managing file system operations, including folder structure and configuration injection for different platforms.

Constructors

FileService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

cleanupFirebaseConfig(String flavor) → void
cleanupFlavors(List<String> deletedFlavors) → void
Removes files and directories associated with deleted flavors.
createStructure() → void
Creates the necessary directory structure for flavors.
formatDirectory(String path) → void
formatFile(String path) → void
getOrphanedFlavors(List<String> currentFlavors) Set<String>
injectFirebase({required bool separate, String? flavor}) → void
Injects Firebase initialization code into the entry point files. If separate is true, it injects into lib/main/main_<flavor>.dart. Otherwise, it injects into lib/main.dart.
removeFirebaseFromContent(String content) String
removeVSCodeLaunchConfig() → void
renameFlavor({required String oldName, required String newName, required AppLogger log}) → void
updateTests() → void
updateVSCodeLaunchConfig() → void