PubspecService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addAssets(
List< String> assetPaths) → void -
addDependency(
String name, String version) → void -
getAssetsWithPrefix(
String prefix) → List< String> -
hasDependency(
String name) → bool -
removeAssets(
List< String> assetPaths) → void -
removeDependency(
String name) → void