RuntimeConfigService class
Service for generating the ENV (.env.<flavor>) based runtime config.
Values are stored in .env files and loaded at app startup via flutter_dotenv.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildRunArgs(
FlavorConfig config, String flavor, {List< String> extraArgs = const []}) → List<String> -
cleanupFlavorFiles(
List< String> deletedFlavors, FlavorConfig config) → void -
generateAppConfig(
FlavorConfig config) → void -
generateFlavorFiles(
FlavorConfig config) → void -
generateMainBoilerplate(
String flavor, FlavorConfig config) → String -
generateSingleMainBoilerplate(
FlavorConfig config) → String -
integrateMainFile(
String path, FlavorConfig config, {String? flavor}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
renameFlavorFiles(
String oldName, String newName, FlavorConfig config) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateEnvFile(
String flavor, Map< String, dynamic> values) → void -
validate(
FlavorConfig config) → List< String> -
validateFlavorReadyToRun(
FlavorConfig config, String flavor, AppLogger log) → bool -
Validates that both the .env file and entry-point file exist for
flavor. Logs errors vialogand returns false if either is missing.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited