AppLogger class

A wrapper around Logger to provide consistent logging and user prompts across the application, with added validation (e.g., Arabic character detection).

Constructors

AppLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

chooseAny(String message, {required List<String> choices, List<String>? defaultValues}) List<String>
chooseOne(String message, {required List<String> choices, String? defaultValue}) String
confirm(String message, {bool defaultValue = false}) bool
Prompts the user for a Yes/No confirmation.
error(String message) → void
info(String message) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prompt(String message, {String? defaultValue}) String
Prompts the user for input with an optional defaultValue. Retries if the input contains invalid characters (e.g., Arabic).
success(String message) → void
toString() String
A string representation of this object.
inherited
warn(String message) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited