FirebaseCommand class

Command to set up and configure Firebase for different flavors.

Constructors

FirebaseCommand({AppLogger? logger, bool fromHook = false})
Creates a new FirebaseCommand with an optional logger.

Properties

fromHook bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute({String? targetFlavor}) Future<void>
Executes the Firebase configuration process. If targetFlavor is provided, only that flavor is configured.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkAndReinit(AppLogger log, {String? targetFlavor}) Future<void>
promptForFirebaseConfig(AppLogger log, FlavorConfig config) FirebaseConfig
Prompts the user for Firebase configuration. Reused by InitWizard to avoid duplicating the strategy/project-ID prompt logic.