InitCommand class

Command to initialize the project with flavor configuration.

Constructors

InitCommand({AppLogger? logger})
Creates a new InitCommand with an optional logger.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(List<String> args) Future<void>
Starts the initialization wizard or loads from a file if the '--from' flag is provided.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited