SetupRunner class
Constructors
- SetupRunner({AppLogger? logger})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replaceFlavor(
{required String oldFlavor, required String newFlavor}) → Future< void> -
reset(
[bool excludeValidation = false]) → void -
run(
FlavorConfig config, {String? newFlavor, bool skipFirebase = false}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited