AndroidService class
Service for managing Android-specific flavor configurations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
reset(
{required FlavorConfig config, AppLogger? logger}) → void - Removes flavor configurations from Android build files and manifest.
-
setupFlavors(
{required FlavorConfig config, AppLogger? logger}) → void - Sets up product flavors in build.gradle (Groovy or KTS) and updates AndroidManifest.